@@ -17,18 +17,11 @@ has note        => (is => "rw", isa => "Str");
 has histories   => (is => "rw", isa => "ArrayRef", lazy_build => 1);
 
 sub create {
-    my ($self, %attr) = @_;
+    my ($class, %attr) = @_;
 
-    if (%attr) {
-        while (my ($k, $v) = each(%attr)) {
-            $self->$k($v);
-        }
-    }
-
-    my $mech = $self->connection->get_project_overview->mechanize;
-
-    $mech->follow_link( url_regex => qr[/issues/new$] );
+    my $self = $class->new(%attr);
 
+    my $mech = $self->connection->get_new_issue_page()->mechanize;
     $mech->form_id("issue-form");
     $mech->field("issue[subject]" => $self->subject);
     $mech->field("issue[description]" => $self->description);
@@ -41,7 +34,7 @@ sub create {
     if ($mech->uri =~ m[/issues(?:/show)?/(\d+)$]) {
         my $id = $1;
         $self->id($id);
-        return $id;
+        return $self;
     }
 }
 
@@ -51,35 +44,28 @@ use HTML::WikiConverter;
 use Encode;
 
 sub load {
-    my ($self, $id) = @_;
+    my ($class, %attr) = @_;
+    die "should specify ticket id when loading it." unless defined $attr{id};
+    die "should specify connection object when loading tickets." unless defined $attr{connection};
 
-    my $mech = $self->connection->get_project_overview->mechanize;
-    $mech->submit_form(
-        form_number => 1,
-        fields => {
-            q => "#" . $id
-        }
-    );
+    my $self = $class->new(%attr);
+    return $self->refresh;
+}
 
-    unless ($mech->response->is_success) {
-        die "Failed to create a new ticket\n";
-    }
+sub refresh {
+    my ($self) = @_;
+    die "Cannot lookup ticket histories without id.\n" unless $self->id;
 
-    my $html = $mech->content;
-
-    # my $html = io("/tmp/issue.html")->utf8->all;
-
-    my $p = pQuery($html);
+    my $id = $self->id;
+    eval '$self->connection->get_issues_page($id)';
+    return if $@;
 
+    my $p = pQuery($self->connection->mechanize->content);
     my $wc = new HTML::WikiConverter( dialect => 'Markdown' );
-
     my $description = $wc->html2wiki( Encode::encode_utf8($p->find(".issue .wiki")->html) );
-
     my $subject = $p->find(".issue h3")->text;
-
     my $status = $p->find(".issue .status")->eq(1)->text;
 
-    $self->id($id);
     $self->subject($subject);
     $self->description($description);
     $self->status($status);
@@ -91,7 +77,7 @@ sub save {
     my ($self) = @_;
     die "Cannot save a ticket without id.\n" unless $self->id;
 
-    my $mech = $self->connection->get_issues($self->id)->mechanize;
+    my $mech = $self->connection->get_issues_page($self->id)->mechanize;
     $mech->follow_link( url_regex => qr[/issues/\d+/edit$] );
 
     $mech->form_id("issue-form");
@@ -112,10 +98,37 @@ sub save {
     return $self;
 }
 
+sub destroy {
+    my ($self) = @_;
+    die "Cannot delete the ticket without id.\n" unless $self->id;
+
+    my $id = $self->id;
+
+    $self->connection->get_issues_page($id);
+    
+    my $mech = $self->connection->mechanize;
+    my $link = $mech->find_link(url_regex => qr[/issues/${id}/destroy$]);
+
+    die "Your cannot delete the ticket $id.\n" unless $link;
+
+    my $html = $mech->content;
+    my $delete_form = "<form name='net_redmine_delete_issue' method=\"POST\" action=\"@{[ $link->url_abs ]}\"><input type='hidden' name='_method' value='post'></form>";
+    $html =~ s/<body>/<body>${delete_form}/;
+    $mech->update_html($html);
+
+    $mech->form_number(1);
+    $mech->submit;
+
+    die "Failed to delete the ticket\n" unless $mech->response->is_success;
+
+    $self->id(-1);
+    return $self;
+}
+
 sub _build_histories {
     my ($self) = @_;
     die "Cannot lookup ticket histories without id.\n" unless $self->id;
-    my $mech = $self->connection->get_issues($self->id)->mechanize;
+    my $mech = $self->connection->get_issues_page($self->id)->mechanize;
 
     my $p = pQuery($mech->content);
 
@@ -151,4 +164,3 @@ Net::Redmine::Ticket - Represents a ticket.
 
 
 =cut
-
